<!--
Copyright (c) 2025 Dave Tofflemire, SigilDERG Project
Licensed under the GNU Affero General Public License v3.0 (AGPLv3).
Commercial licenses are available. Contact: davetmire85@gmail.com
-->

# ADR-NNN: Title

## Status

[Proposed | Accepted | Deprecated | Superseded by ADR-XXX]

## Context

What is the issue that we're seeing that is motivating this decision or change?

## Decision

What is the change that we're proposing and/or doing?

## Consequences

### Positive

- List positive consequences

### Negative

- List negative consequences

### Neutral

- List neutral consequences

## Alternatives Considered

### Alternative 1: [Name]

Description of the alternative and why it was rejected.

### Alternative 2: [Name]

Description of the alternative and why it was rejected.

## Related

- Links to related ADRs, documents, or issues





